#  You may distribute under the terms of either the GNU General Public License
#  or the Artistic License (the same terms as Perl itself)
#
#  (C) Paul Evans, 2007 -- leonerd@leonerd.org.uk

package IO::Async::Set::Select;

use strict;

our $VERSION = '0.10';

use base qw( IO::Async::Loop::Select IO::Async::Set );

use warnings qw();

=head1 NAME

C<IO::Async::Set::Select> - backward-compatibility wrapper around
C<IO::Async::Loop::Select>

=head1 SYNOPSIS

This class should not be used in new code, and is provided for backward
compatibility for older applications that still use it. It has been renamed
to C<IO::Async::Loop::Select>. Any application using this class should simply
change

 use IO::Async::Set::Select;

 my $set = IO::Async::Set::Select->new( .... );

into

 use IO::Async::Loop::Select;

 my $loop = IO::Async::Loop::Select->new( .... );

The behaviour has not otherwise changed.

=cut

=head1 CONSTRUCTOR

=cut

=head2 $set = IO::Async::Set::Select->new( %params )

This function wraps a call to C<< IO::Async::Set::Select->new() >>.

=cut

sub new
{
   my $class = shift;
   my ( %params ) = @_;

   warnings::warnif 'deprecated',
      "Use of IO::Async::Set::Select is deprecated; use IO::Async::Loop::Select instead";

   return $class->SUPER::new( %params );
}

# Keep perl happy; keep Britain tidy
1;

__END__

=head1 SEE ALSO

=over 4

=item *

L<IO::Async::Loop::Select> - a Loop using the C<select()> syscall

=back

=head1 AUTHOR

Paul Evans E<lt>leonerd@leonerd.org.ukE<gt>
